@@ -18,6 +18,9 @@ class NestCommand(NestProvider):
         # return NestRoute.__name__
         return self.commandName
 
+    def getName(self):
+        return self.commandName
+
     def parseArguments(self, parser):
         arguments = [ag for ag in dir(self.cls) if isinstance(
             getattr(self.cls, ag), NestCommandArgument)]
@@ -35,7 +38,7 @@ class NestCommand(NestProvider):
                 **argument.kwargs,
             )
 
-    def setup(self, module, context):
-        self._setup(module, context)
+    def setupProvider(self, module, context):
+        self._setupProvider(module, context)
         # args = sys.argv[1:]
         # self.provider.run(inquirer, args)
